@@ -3,12 +3,12 @@ package inc::MBX::Alien::FLTK::Utility;
     use strict;
     use warnings;
     use Config qw[%Config];
-    use File::Spec::Functions qw[splitpath catpath catdir rel2abs canonpath];
+    use File::Spec::Functions qw[splitpath catpath catdir rel2abs];
     use File::Basename qw[];
     use File::Find qw[find];
     use Exporter qw[import];
     our @EXPORT_OK
-        = qw[can_run run _o _a _exe _dll find_h find_lib _path _abs _rel _dir _file _split];
+        = qw[can_run run _o _a _exe _dll _path _abs _rel _dir _file _split];
 
     sub can_run {    # Snagged from IPC::CMD and trimmed for my use
         my ($prog) = @_;
@@ -64,45 +64,6 @@ package inc::MBX::Alien::FLTK::Utility;
     sub _file  { File::Basename::fileparse(shift); }
     sub _dir   { File::Basename::dirname(shift); }
     sub _split { File::Spec->splitpath(@_) }
-
-    sub find_lib {
-        my ($find, $dir) = @_;
-        no warnings 'File::Find';
-        $find =~ s[([\+\*\.])][\\$1]g;
-        $dir ||= $Config{'libpth'};
-        $dir = canonpath($dir);
-        my $lib;
-        find(
-            sub {
-                $lib = canonpath(rel2abs($File::Find::dir))
-                    if $_ =~ qr[lib$find$Config{'_a'}];
-            },
-            split ' ',
-            $dir
-        ) if $dir;
-        return $lib;
-    }
-
-    sub find_h {
-        my ($file, $dir) = @_;
-        no warnings 'File::Find';
-        $dir ||= $Config{'incpath'} . ' ' . $Config{'usrinc'};
-        $dir  = canonpath($dir);
-        $file = canonpath($file);
-        my $h;
-        find(
-            {wanted => sub {
-                 return if !-d $_;
-                 $h = canonpath(rel2abs($_))
-                     if -f _path($_, $file);
-             },
-             no_chdir => 1
-            },
-            split ' ',
-            $dir
-        ) if $dir;
-        return $h;
-    }
     1;
 }
 
