@@ -3,40 +3,54 @@ package Alien::FLTK;
     use strict;
     use warnings;
     use File::Spec::Functions qw[catdir rel2abs canonpath];
-    use File::ShareDir;
-    use YAML::Tiny;
-    our $BASE = 0; our $SVN = 7008; our $DEV = 5; our $VERSION = sprintf('%d.%05d' . ($DEV ? '_%03d' : ''), $BASE, $SVN, $DEV);
+    our $BASE = 0; our $SVN = 7008; our $DEV = 10; our $VERSION = sprintf('%d.%05d' . ($DEV ? '_%03d' : ''), $BASE, $SVN, $DEV);
 
-    sub md5 {
+    sub _md5 {
         return {gz  => 'adfc4746c7b2bf7e895612d118ab8f2f',
                 bz2 => '7589b3523045b7c059026de21564e68d'
         };
     }
-    my ($basedir)
-        = (grep { -d $_ && -f catdir($_, 'config.yml') } map { rel2abs($_) } (
-                eval { File::ShareDir::dist_dir('Alien-FLTK') }, '../share/',
-                '../../share/'
-           )
-        );
-    my $_config = do {
-        my $yaml = YAML::Tiny->read(catdir($basedir, 'config.yml'));
-        warn 'Failed to load Alien::FLTK config: ' . YAML::Tiny->errstr()
-            if !$yaml;
-        $yaml ? $yaml->[0] : {};
-    };
-    sub new { return bless \$|, shift; }
-    sub config   { return $_config; }
+    sub _unique_file { return 'src/Fl.cxx' }
+
+    sub new {
+        my ($class, $overrides) = @_;    # XXX - overrides are unsupported
+        my $self;
+        {
+            require File::ShareDir;
+            ($self->{'basedir'})
+                = (grep { -d $_ && -f catdir($_, 'config.yml') }
+                       map { rel2abs($_) } (
+                              eval { File::ShareDir::dist_dir('Alien-FLTK') },
+                              'share', '../share', '../../share'
+                       )
+                );
+        }
+        if (!defined $self->{'basedir'}) {
+            warn 'Fail';
+            return ();
+        }
+        $self->{'define'} = do {
+            require YAML::Tiny;
+            my $yaml
+                = YAML::Tiny->read(catdir($self->{'basedir'}, 'config.yml'));
+            warn 'Failed to load Alien::FLTK config: ' . YAML::Tiny->errstr()
+                if !$yaml;
+            $yaml ? $yaml->[0] : {};
+        };
+        return bless $self, shift;
+    }
+    sub config   { return +shift->{'define'}; }
     sub revision { return $SVN; }
-    sub branch   { return $_config->{'branch'} }
+    sub branch   { return +shift->{'define'}->{'branch'} }
 
     sub include_dirs {
         my ($self) = @_;
-        return canonpath($basedir . '/include');
+        return canonpath($self->{'basedir'} . '/include');
     }
 
     sub library_path {
         my ($self) = @_;
-        return canonpath($basedir . '/libs');
+        return canonpath($self->{'basedir'} . '/libs');
     }
     sub cflags { return shift->cxxflags(); }
 
@@ -101,7 +115,7 @@ package Alien::FLTK;
     sub capabilities {
         my ($self) = @_;
         my @caps;
-        push @caps, 'gl' if $self->config->{'config'}{'HAVE_GL'};
+        push @caps, 'gl' if $self->config->{'define'}{'HAVE_GL'};
 
         # TODO: images, forms, static(?)
         return @caps;
@@ -390,6 +404,6 @@ clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 L<Alien::FLTK|Alien::FLTK> is based in part on the work of the FLTK project.
 See http://www.fltk.org/.
 
-=for git $Id: FLTK.pm 6c03764 2010-01-19 18:31:34Z sanko@cpan.org $
+=for git $Id: FLTK.pm cbdb5a4 2010-01-27 20:31:08Z sanko@cpan.org $
 
 =cut
